@@ -2,6 +2,7 @@ mod table;
 mod serde;
 mod describe;
 
+use comfy_table::Table;
 pub use output::Terminal;
 pub use output::OutputType;
 
@@ -55,6 +56,18 @@ mod error {
     }
 }
 
+pub trait DisplayTable {
+    fn print_std(&self, indent: u8);
+}
+
+impl DisplayTable for Table {
+    fn print_std(&self, indent: u8) {
+        for line in self.to_string().split('\n') {
+            println!("{}{}", " ".repeat(indent as usize), line);
+        }
+    }
+}
+
 #[allow(clippy::module_inception)]
 mod output {
 
@@ -62,12 +75,11 @@ mod output {
 
     use clap::ArgEnum;
     use serde::Serialize;
-    use prettytable::format;
-    use prettytable::Table;
-    use prettytable::row;
-    use prettytable::cell;
 
-    use super::TableOutputHandler;
+    use comfy_table::Table;
+    use comfy_table::{Row, Cell};
+
+    use super::{TableOutputHandler, DisplayTable};
     use super::TableRenderer;
     use super::SerdeRenderer;
     use super::DescribeObjectHandler;
@@ -150,18 +162,23 @@ mod output {
 
             // Create the table
             let mut table = Table::new();
-            table.set_format(*format::consts::FORMAT_CLEAN);
 
             for (key, val_opt) in kv_values {
+                let mut row = Row::new();
+
                 if let Some(val) = val_opt {
-                    table.add_row(row!(key, ":".to_owned(), val));
+                    row.add_cell(Cell::new(format!("{}{}{}", key, ":".to_owned(), val)));
                 } else {
-                    table.add_row(row!(key));
+                    row.add_cell(Cell::new(key.to_string()));
                 }
+
+                table.add_row(row);
             }
 
+            table.load_preset(comfy_table::presets::NOTHING);
+
             // print table to stdout
-            table.printstd();
+            table.print_std(2);
         }
     }
 }
